#!/usr/bin/env pypy

###############################################################################
# Mjöllnir -- a simulator of the magnetic properties of polynuclear complexes
# Copyright (c) 2009--2020 Anton S. Lytvynenko, Elena A. Mikhalyova
#
# The authors thanks to Dr. V. A. Bogaenko and to Sergei Litvinenko for
# technical help and valuable discussion.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
###############################################################################

from subprocess import Popen, PIPE
import os

class mj_eigensolver_caller:
    def __init__(self, eigensolver, mtxlistfname):
        logfile = open("mj_eigensolver_log","w")
        self.communicator = Popen(eigensolver,stdout=PIPE, stdin=PIPE, stderr=logfile)
        self.communicator.stdin.write(mtxlistfname+os.linesep)
    def calculate(self, coefs):
        for i in coefs:
            self.communicator.stdin.write(str(i)+os.linesep)
        self.communicator.stdin.flush()
        nvalues = int(self.communicator.stdout.readline().strip())
        eigs = []
        for i in range(nvalues):
            v = self.communicator.stdout.readline().strip()
            if v!="":
                eigs.append(float(v))
        return eigs