#!/usr/bin/env pypy

###############################################################################
# Mjöllnir -- a simulator of the magnetic properties of polynuclear complexes
# Copyright (c) 2009--2020 Anton S. Lytvynenko, Elena A. Mikhalyova
#
# The authors thanks to Dr. V. A. Bogaenko and to Sergei Litvinenko for
# technical help and valuable discussion.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
###############################################################################

import numpy as np
import sys, os

def eig_log(mess):
    logfile.write(mess+os.linesep)
    logfile.flush()

logfile = open("mj_eigensolver_log","w")

mtx_list_fname = raw_input().strip() # Filename of file containing mtx filenames list is expected
eig_log("Read mtx list file name: "+mtx_list_fname)
mtx_list_file = open(mtx_list_fname, "r")
# First line of the file shall contain two integers -- number of matrix files and their total dimension
n_matrices, matrix_dim = map(lambda x: int(x.strip()), mtx_list_file.readline().split())
mtx_list = [] # List of matrices loaded from disk
for n in range(n_matrices):
    mtx = []
    mfname = mtx_list_file.readline().strip()
    mfin = open(mfname,"r")
    nels = int(mfin.readline().strip())
    for m in range(nels):
        i, j, value = mfin.readline().split()
        i = int(i.strip())
        j = int(j.strip())
        value = complex(value.strip())
        mtx.append((i,j,value))
    mtx_list.append(mtx)
    mfin.close()
mtx_list_file.close()

#print mtx_list


while True:
    try:
        A = np.zeros((matrix_dim,matrix_dim),dtype=np.float64) # Nullified initial matrix generated
        for n in range(n_matrices):
            coef = float(raw_input()) # We expect a list of coefficients to be multiplied by the corresponding matrices
            eig_log("Read coefficient number "+str(n)+": "+str(coef))
            for i,j,value in mtx_list[n]:
                A[i-1,j-1]+=value*coef
        eigenvalues = np.linalg.eigvalsh(A)
        print matrix_dim
        for k in eigenvalues:
            print k
        sys.stdout.flush()
    except (EOFError, ValueError) as e:
        break
