#!/usr/bin/env pypy

###############################################################################
# Mjöllnir -- a simulator of the magnetic properties of polynuclear complexes
# Copyright (c) 2009--2020 Anton S. Lytvynenko, Elena A. Mikhalyova
#
# The authors thanks to Dr. V. A. Bogaenko and to Sergei Litvinenko for
# technical help and valuable discussion.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
###############################################################################

# In this module I shall define a list of supported analytical functions and an function to pick them by name
# All these functions get a list of floats (temperatures) and return a list of xT values

import re
import math

from mj_const import *

def cu2 (temps, frag_num, params_script):
    exec(params_script)
    exec("g = m"+str(frag_num)+"_g")
    exec("J = m"+str(frag_num)+"_J")
    answer = []
    for i in temps:
        x = (2*Nbk*g*g/(1+(1.0/3.0)*math.exp(-2*J/(k*i))))/i
        answer.append((i,x))
    return answer

class mj_fragment_equation:
    'A distinct fragment of Mjollir model with xT calculation based on librarian analytical function (e.g. Bleany-Bowers equation)'
    def __init__(self, frag_num, equation_name):
        self.frag_num = frag_num
        self.frag_type = "equation"
        self.equation_name = equation_name
    def parse(self, test=False):
        'This routine tries to extract the name, and, if present, some additional parameters'
        if self.equation_name == "Cu2":
            self.params_list = ["m"+str(self.frag_num)+"_g","m"+str(self.frag_num)+"_J"]
            self.func = cu2
        else:
            raise Exception("mj_fragment_equation.parse : equation is not found for the model: "+self.equation_name)
    def read(self):
        'No need to store something, so we just parse the model again, it is inexpensive'
        self.parse()
    def save(self):
        pass
    def get_params_list(self):
        'This routine checks if params_list is formed (i.e. if the fragment is parsed) and returns it if yes'
        if not self.params_list:
            raise Exception("mj_fragment_equation.get_params_list : trying to get list of parameters from unparsed fragment")
        return self.params_list
    def x(self,temps,params_script):
        'This routine returns chi values for the desired set of temperatures'
        return self.func(temps, self.frag_num, params_script)
