#!/usr/bin/env pypy

###############################################################################
# Mjöllnir -- a simulator of the magnetic properties of polynuclear complexes
# Copyright (c) 2009--2020 Anton S. Lytvynenko, Elena A. Mikhalyova
#
# The authors thanks to Dr. V. A. Bogaenko and to Sergei Litvinenko for
# technical help and valuable discussion.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
###############################################################################

import re

mj_lanthanides_config = {}

mj_lanthanides_config["supported_ions"] = ['Ce', 'Pr', 'Nd', 'Pm', 'Sm', 'Eu', 'Tb', 'Dy', 'Ho', 'Er', 'Tm', 'Yb']

class mj_fragment_lanthanide:
    'A distinct fragment of Mjollir model --- lone specially treated lanthanide ion'
    def __init__(self, frag_num, calc_type):
        self.frag_num = frag_num
        self.frag_type = "lanthanide"
        self.calc_type = calc_type
        pass
    def parse(self, test=False):
        expr = re.compile("^(.+)\((.+)\)$") # We expect something like "Eu(ZFS)" in self.calc_type
        ion_type, calc_way = re.findall(expr, self.calc_type)
        self.ion_type = ion_type.strip()
        if self.ion_type not in mj_lanthanides_config["supported_ions"]:
            raise Exception("mj_fragment_lanthanide.parse(): unsupported lanthanide type \""+self.ion_type+"\"")
        self.calc_way = calc_way.strip()
        if self.calc_way != "ZFS":
            raise Exception("mj_fragment_lanthanide.parse(): only ZFS treatment of lanthanide ion is supported yet")
        pass
        # To be continued
